@@ -4,9 +4,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-08-24'; # DATE
+our $DATE = '2021-08-26'; # DATE
 our $DIST = 'Log-ger-App'; # DIST
-our $VERSION = '0.020'; # VERSION
+our $VERSION = '0.021'; # VERSION
 
 our $DEBUG = defined($ENV{LOG_GER_APP_DEBUG}) ? $ENV{LOG_GER_APP_DEBUG} : 0;
 
@@ -116,6 +116,13 @@ sub import {
         %{ $extra_conf // {} },
     );
 
+    my %off_categories = (
+        # some known categories that are not normally logged to screen or
+        # (error) file log
+        #'_dumps'  => 'off', # e.g. in download-bca, download-mandiri
+        '_access' => 'off', # e.g. in WWW::PAUSE::Simple
+    );
+
     # add Screen
     {
         last if $is_daemon;
@@ -134,6 +141,7 @@ sub import {
         $conf{outputs}{Screen} = {
             conf   => { formatter => sub { "$progname: $_[0]" } },
             level  => $olevel,
+            category_level => \%off_categories,
             layout => [Pattern => {format => $fmt}],
         };
     }
@@ -169,6 +177,7 @@ sub import {
         $conf{outputs}{File} = {
             conf   => { path => $file_path },
             level  => $olevel,
+            category_level => \%off_categories,
             layout => [Pattern => {format => $fmt}],
         };
     }
@@ -185,6 +194,7 @@ sub import {
         $conf{outputs}{Syslog} = {
             conf => { ident => $progname, facility => 'daemon' },
             level => $olevel,
+            category_level => \%off_categories,
         };
     }
 
@@ -224,7 +234,7 @@ Log::ger::App - An easy way to use Log::ger in applications
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 SYNOPSIS
 
